@@ -73,9 +73,15 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
     var fileInfo = new QFileInfo(uiFile);
     if (!fileInfo.exists() && !fileInfo.isAbsolute()) {
         uiFile = basePath + "/" + uiFile;
+
+        fileInfo = new QFileInfo(uiFile);
+        if (!fileInfo.exists()) {
+            uiFile = ":" + uiFile;
+            fileInfo = new QFileInfo(uiFile);
+        }
     }
 
-    fileInfo = new QFileInfo(uiFile);
+    //fileInfo = new QFileInfo(uiFile);
     if (!fileInfo.exists()) {
         qWarning("WidgetFactory: File %1 does not exist".arg(uiFile));
         return undefined;
@@ -104,6 +110,8 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
         WidgetFactory.installComboBoxEventFilter(formWidget);
     }
 
+    WidgetFactory.adjustIcons(fileInfo.absolutePath(), formWidget);
+
     return formWidget;
 };
 
@@ -955,6 +963,7 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
                     w.maximumWidth = 75;
                 }
             }
+
             a = targetWidget.addWidget(w);
             a.objectName = w.objectName + "Action";
             ret.push(a);
@@ -970,6 +979,33 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
     return ret;
 };
 
+WidgetFactory.adjustIcons = function(includeBasePath, widget) {
+    if (!RSettings.hasDarkGuiBackground()) {
+        return;
+    }
+
+    if (!isFunction(widget.children)) {
+        return;
+    }
+
+    var children = widget.children();
+    for(var i=0;i<children.length;++i) {
+        var w=children[i];
+
+        // adjust icon for dark themes:
+        if (isOfType(w, QToolButton)) {
+            var iconFile = includeBasePath + "/" + w.objectName + "-inverse.svg";
+            if (new QFileInfo(iconFile).exists()) {
+                w.icon = new QIcon(iconFile);
+            }
+        }
+        else {
+            WidgetFactory.adjustIcons(includeBasePath, w);
+        }
+
+    }
+};
+
 /**
  * Adds an "insert symbol" menu entry to the context menu of the given
  * line edit.
@@ -988,6 +1024,7 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
         // TODO: split into submenus (math, greek, ...):
         var symbols = [
                 ["\u00F8", qsTr("Diameter")],
+                ["\u2312", qsTr("Arc")],
                 ["\u00B0", qsTr("Degree")],
                 ["\u00B1", qsTr("Plus/Minus")],
                 ["\u2248", qsTr("Almost equal to")],
@@ -1047,25 +1084,25 @@ WidgetFactory.initTextBrowser = function(textBrowser, linkHandler, slot) {
     textBrowser.anchorClicked.connect(linkHandler, slot);
 };
 
-WidgetFactory.initWebView = function(webView, linkHandler, slot) {
-    var webPage = webView.page();
-    webPage.linkDelegationPolicy = QWebPage.DelegateExternalLinks;
-    webPage.linkClicked.connect(linkHandler, slot);
-    var webSettings = webView.settings();
-    webSettings.setFontFamily(QWebSettings.StandardFont, EAction.getMainWindow().font.family());
-    if (RS.getSystemId()==="osx") {
-        webSettings.setFontSize(QWebSettings.DefaultFontSize, EAction.getMainWindow().font.pointSize());
-    }
+//WidgetFactory.initWebView = function(webView, linkHandler, slot) {
+//    var webPage = webView.page();
+//    webPage.linkDelegationPolicy = QWebPage.DelegateExternalLinks;
+//    webPage.linkClicked.connect(linkHandler, slot);
+//    var webSettings = webView.settings();
+//    webSettings.setFontFamily(QWebSettings.StandardFont, EAction.getMainWindow().font.family());
+//    if (RS.getSystemId()==="osx") {
+//        webSettings.setFontSize(QWebSettings.DefaultFontSize, EAction.getMainWindow().font.pointSize());
+//    }
 
-    if (!RSettings.isQt(5)) {
-        // make web view transparent:
-        var palette = webView.palette;
-        palette.setBrush(QPalette.Base, new QColor(0,0,0,0));
-        webPage.palette = palette;
+//    if (!RSettings.isQt(5)) {
+//        // make web view transparent:
+//        var palette = webView.palette;
+//        palette.setBrush(QPalette.Base, new QColor(0,0,0,0));
+//        webPage.palette = palette;
 
-        webView.setAttribute(Qt.WA_OpaquePaintEvent, false);
-    }
-};
+//        webView.setAttribute(Qt.WA_OpaquePaintEvent, false);
+//    }
+//};
 
 WidgetFactory.initLayerCombo = function(comboBox, doc) {
     if (isNull(doc)) {
